@@ -70,6 +70,7 @@ var annotated_dup =
     [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
     [ "pw_impl_node", "structpw__impl__node.html", null ],
     [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
+    [ "pw_impl_node_rt_events", "structpw__impl__node__rt__events.html", "structpw__impl__node__rt__events" ],
     [ "pw_impl_port", "structpw__impl__port.html", null ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
     [ "pw_link", "structpw__link.html", null ],
@@ -122,6 +123,9 @@ var annotated_dup =
     [ "pw_registry_methods", "structpw__registry__methods.html", "structpw__registry__methods" ],
     [ "pw_resource", "structpw__resource.html", null ],
     [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
+    [ "pw_security_context", "structpw__security__context.html", null ],
+    [ "pw_security_context_events", "structpw__security__context__events.html", "structpw__security__context__events" ],
+    [ "pw_security_context_methods", "structpw__security__context__methods.html", "structpw__security__context__methods" ],
     [ "pw_session", "structpw__session.html", null ],
     [ "pw_session_events", "structpw__session__events.html", "structpw__session__events" ],
     [ "pw_session_info", "structpw__session__info.html", "structpw__session__info" ],
@@ -132,16 +136,32 @@ var annotated_dup =
     [ "pw_thread_loop", "structpw__thread__loop.html", null ],
     [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
     [ "pw_time", "structpw__time.html", "structpw__time" ],
+    [ "pw_timer", "structpw__timer.html", "structpw__timer" ],
     [ "pw_work_queue", "structpw__work__queue.html", null ],
-    [ "pwtest_context", "structpwtest__context.html", null ],
-    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
-    [ "pwtest_suite", "structpwtest__suite.html", null ],
-    [ "pwtest_test", "structpwtest__test.html", null ],
+    [ "spa_audio_aec", "structspa__audio__aec.html", "structspa__audio__aec" ],
+    [ "spa_audio_aec_events", "structspa__audio__aec__events.html", "structspa__audio__aec__events" ],
+    [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
+    [ "spa_audio_aec_methods", "structspa__audio__aec__methods.html", "structspa__audio__aec__methods" ],
     [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
+    [ "spa_audio_info_aac", "structspa__audio__info__aac.html", "structspa__audio__info__aac" ],
+    [ "spa_audio_info_ac3", "structspa__audio__info__ac3.html", "structspa__audio__info__ac3" ],
+    [ "spa_audio_info_alac", "structspa__audio__info__alac.html", "structspa__audio__info__alac" ],
+    [ "spa_audio_info_amr", "structspa__audio__info__amr.html", "structspa__audio__info__amr" ],
+    [ "spa_audio_info_ape", "structspa__audio__info__ape.html", "structspa__audio__info__ape" ],
     [ "spa_audio_info_dsd", "structspa__audio__info__dsd.html", "structspa__audio__info__dsd" ],
     [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
+    [ "spa_audio_info_dts", "structspa__audio__info__dts.html", "structspa__audio__info__dts" ],
+    [ "spa_audio_info_eac3", "structspa__audio__info__eac3.html", "structspa__audio__info__eac3" ],
+    [ "spa_audio_info_flac", "structspa__audio__info__flac.html", "structspa__audio__info__flac" ],
     [ "spa_audio_info_iec958", "structspa__audio__info__iec958.html", "structspa__audio__info__iec958" ],
+    [ "spa_audio_info_mp3", "structspa__audio__info__mp3.html", "structspa__audio__info__mp3" ],
+    [ "spa_audio_info_mpegh", "structspa__audio__info__mpegh.html", "structspa__audio__info__mpegh" ],
+    [ "spa_audio_info_opus", "structspa__audio__info__opus.html", "structspa__audio__info__opus" ],
+    [ "spa_audio_info_ra", "structspa__audio__info__ra.html", "structspa__audio__info__ra" ],
     [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
+    [ "spa_audio_info_truehd", "structspa__audio__info__truehd.html", "structspa__audio__info__truehd" ],
+    [ "spa_audio_info_vorbis", "structspa__audio__info__vorbis.html", "structspa__audio__info__vorbis" ],
+    [ "spa_audio_info_wma", "structspa__audio__info__wma.html", "structspa__audio__info__wma" ],
     [ "spa_audio_layout_info", "structspa__audio__layout__info.html", "structspa__audio__layout__info" ],
     [ "spa_buffer", "structspa__buffer.html", "structspa__buffer" ],
     [ "spa_buffer_alloc_info", "structspa__buffer__alloc__info.html", "structspa__buffer__alloc__info" ],
@@ -156,6 +176,9 @@ var annotated_dup =
     [ "spa_dbus_connection", "structspa__dbus__connection.html", "structspa__dbus__connection" ],
     [ "spa_dbus_connection_events", "structspa__dbus__connection__events.html", "structspa__dbus__connection__events" ],
     [ "spa_dbus_methods", "structspa__dbus__methods.html", "structspa__dbus__methods" ],
+    [ "spa_debug_context", "structspa__debug__context.html", "structspa__debug__context" ],
+    [ "spa_debug_file_ctx", "structspa__debug__file__ctx.html", "structspa__debug__file__ctx" ],
+    [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", "structspa__debug__log__ctx" ],
     [ "spa_device", "structspa__device.html", "structspa__device" ],
     [ "spa_device_events", "structspa__device__events.html", "structspa__device__events" ],
     [ "spa_device_info", "structspa__device__info.html", "structspa__device__info" ],
@@ -163,8 +186,14 @@ var annotated_dup =
     [ "spa_device_object_info", "structspa__device__object__info.html", "structspa__device__object__info" ],
     [ "spa_dict", "structspa__dict.html", "structspa__dict" ],
     [ "spa_dict_item", "structspa__dict__item.html", "structspa__dict__item" ],
+    [ "spa_dll", "structspa__dll.html", "structspa__dll" ],
+    [ "spa_error_location", "structspa__error__location.html", "structspa__error__location" ],
     [ "spa_event", "structspa__event.html", "structspa__event" ],
     [ "spa_event_body", "structspa__event__body.html", "structspa__event__body" ],
+    [ "spa_filter_graph", "structspa__filter__graph.html", "structspa__filter__graph" ],
+    [ "spa_filter_graph_events", "structspa__filter__graph__events.html", "structspa__filter__graph__events" ],
+    [ "spa_filter_graph_info", "structspa__filter__graph__info.html", "structspa__filter__graph__info" ],
+    [ "spa_filter_graph_methods", "structspa__filter__graph__methods.html", "structspa__filter__graph__methods" ],
     [ "spa_fraction", "structspa__fraction.html", "structspa__fraction" ],
     [ "spa_graph", "structspa__graph.html", "structspa__graph" ],
     [ "spa_graph_link", "structspa__graph__link.html", "structspa__graph__link" ],
@@ -180,6 +209,7 @@ var annotated_dup =
     [ "spa_i18n_methods", "structspa__i18n__methods.html", "structspa__i18n__methods" ],
     [ "spa_interface", "structspa__interface.html", "structspa__interface" ],
     [ "spa_interface_info", "structspa__interface__info.html", "structspa__interface__info" ],
+    [ "spa_io_async_buffers", "structspa__io__async__buffers.html", "structspa__io__async__buffers" ],
     [ "spa_io_buffers", "structspa__io__buffers.html", "structspa__io__buffers" ],
     [ "spa_io_clock", "structspa__io__clock.html", "structspa__io__clock" ],
     [ "spa_io_latency", "structspa__io__latency.html", "structspa__io__latency" ],
@@ -198,6 +228,7 @@ var annotated_dup =
     [ "spa_log", "structspa__log.html", "structspa__log" ],
     [ "spa_log_methods", "structspa__log__methods.html", "structspa__log__methods" ],
     [ "spa_log_topic", "structspa__log__topic.html", "structspa__log__topic" ],
+    [ "spa_log_topic_enum", "structspa__log__topic__enum.html", "structspa__log__topic__enum" ],
     [ "spa_loop", "structspa__loop.html", "structspa__loop" ],
     [ "spa_loop_control", "structspa__loop__control.html", "structspa__loop__control" ],
     [ "spa_loop_control_hooks", "structspa__loop__control__hooks.html", "structspa__loop__control__hooks" ],
@@ -212,12 +243,16 @@ var annotated_dup =
     [ "spa_meta_cursor", "structspa__meta__cursor.html", "structspa__meta__cursor" ],
     [ "spa_meta_header", "structspa__meta__header.html", "structspa__meta__header" ],
     [ "spa_meta_region", "structspa__meta__region.html", "structspa__meta__region" ],
+    [ "spa_meta_sync_timeline", "structspa__meta__sync__timeline.html", "structspa__meta__sync__timeline" ],
+    [ "spa_meta_videotransform", "structspa__meta__videotransform.html", "structspa__meta__videotransform" ],
     [ "spa_node", "structspa__node.html", "structspa__node" ],
     [ "spa_node_callbacks", "structspa__node__callbacks.html", "structspa__node__callbacks" ],
     [ "spa_node_events", "structspa__node__events.html", "structspa__node__events" ],
     [ "spa_node_info", "structspa__node__info.html", "structspa__node__info" ],
     [ "spa_node_methods", "structspa__node__methods.html", "structspa__node__methods" ],
+    [ "spa_param_dict_info", "structspa__param__dict__info.html", "structspa__param__dict__info" ],
     [ "spa_param_info", "structspa__param__info.html", "structspa__param__info" ],
+    [ "spa_peer_param_info", "structspa__peer__param__info.html", "structspa__peer__param__info" ],
     [ "spa_plugin_loader", "structspa__plugin__loader.html", "structspa__plugin__loader" ],
     [ "spa_plugin_loader_methods", "structspa__plugin__loader__methods.html", "structspa__plugin__loader__methods" ],
     [ "spa_pod", "structspa__pod.html", "structspa__pod" ],
@@ -233,6 +268,7 @@ var annotated_dup =
     [ "spa_pod_choice_body", "structspa__pod__choice__body.html", "structspa__pod__choice__body" ],
     [ "spa_pod_control", "structspa__pod__control.html", "structspa__pod__control" ],
     [ "spa_pod_double", "structspa__pod__double.html", "structspa__pod__double" ],
+    [ "spa_pod_dynamic_builder", "structspa__pod__dynamic__builder.html", "structspa__pod__dynamic__builder" ],
     [ "spa_pod_fd", "structspa__pod__fd.html", "structspa__pod__fd" ],
     [ "spa_pod_float", "structspa__pod__float.html", "structspa__pod__float" ],
     [ "spa_pod_fraction", "structspa__pod__fraction.html", "structspa__pod__fraction" ],
@@ -256,6 +292,7 @@ var annotated_dup =
     [ "spa_poll_event", "structspa__poll__event.html", "structspa__poll__event" ],
     [ "spa_port_info", "structspa__port__info.html", "structspa__port__info" ],
     [ "spa_process_latency_info", "structspa__process__latency__info.html", "structspa__process__latency__info" ],
+    [ "spa_ratelimit", "structspa__ratelimit.html", "structspa__ratelimit" ],
     [ "spa_rectangle", "structspa__rectangle.html", "structspa__rectangle" ],
     [ "spa_region", "structspa__region.html", "structspa__region" ],
     [ "spa_result_device_params", "structspa__result__device__params.html", "structspa__result__device__params" ],
@@ -265,17 +302,21 @@ var annotated_dup =
     [ "spa_result_node_params_data", "structspa__result__node__params__data.html", "structspa__result__node__params__data" ],
     [ "spa_ringbuffer", "structspa__ringbuffer.html", "structspa__ringbuffer" ],
     [ "spa_source", "structspa__source.html", "structspa__source" ],
+    [ "spa_strbuf", "structspa__strbuf.html", "structspa__strbuf" ],
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
+    [ "spa_tag_info", "structspa__tag__info.html", "structspa__tag__info" ],
     [ "spa_thread", "structspa__thread.html", null ],
     [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
     [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
+    [ "spa_type_audio_layout_info", "structspa__type__audio__layout__info.html", "structspa__type__audio__layout__info" ],
     [ "spa_type_info", "structspa__type__info.html", "structspa__type__info" ],
     [ "spa_video_colorimetry", "structspa__video__colorimetry.html", "structspa__video__colorimetry" ],
     [ "spa_video_info", "structspa__video__info.html", "structspa__video__info" ],
     [ "spa_video_info_dsp", "structspa__video__info__dsp.html", "structspa__video__info__dsp" ],
     [ "spa_video_info_h264", "structspa__video__info__h264.html", "structspa__video__info__h264" ],
+    [ "spa_video_info_h265", "structspa__video__info__h265.html", "structspa__video__info__h265" ],
     [ "spa_video_info_mjpg", "structspa__video__info__mjpg.html", "structspa__video__info__mjpg" ],
     [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ]
 ];
\ No newline at end of file
