@@ -58,7 +58,9 @@ var group__spa__node =
       [ "signature_denom", "structspa__io__segment__bar.html#a65f1a61b7161bc2ddfb12e2bec1c51d3", null ],
       [ "bpm", "structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3", null ],
       [ "beat", "structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5", null ],
-      [ "padding", "structspa__io__segment__bar.html#a23933e48afa26296c4b2c2df6470bb12", null ]
+      [ "bar_start_tick", "structspa__io__segment__bar.html#ad1c1cb6cda52db4b3ffbb4dbee804bb0", null ],
+      [ "ticks_per_beat", "structspa__io__segment__bar.html#a7c4acf7c0d30df734669355189d0879f", null ],
+      [ "padding", "structspa__io__segment__bar.html#a34df6bc077aed465af23d8b5b8d74a85", null ]
     ] ],
     [ "spa_io_segment_video", "structspa__io__segment__video.html", [
       [ "flags", "structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248", null ],
@@ -93,7 +95,8 @@ var group__spa__node =
       [ "size", "structspa__io__rate__match.html#ad8a395240a4b89d6be0e67538cf6ad5c", null ],
       [ "rate", "structspa__io__rate__match.html#a8f9575e69576c942758927acba7daeef", null ],
       [ "flags", "structspa__io__rate__match.html#a7b89f4c442e2856faf64abeec186050e", null ],
-      [ "padding", "structspa__io__rate__match.html#a2ef8495597b9368305657a6202944046", null ]
+      [ "delay_frac", "structspa__io__rate__match.html#a63710cb0783f022e8d3e6437b39db70b", null ],
+      [ "padding", "structspa__io__rate__match.html#a79cd6d144071b3ab6415bc4201af9631", null ]
     ] ],
     [ "spa_io_async_buffers", "structspa__io__async__buffers.html", [
       [ "buffers", "structspa__io__async__buffers.html#a97004192f552cb50fee39067e5b07fff", null ]
@@ -171,16 +174,27 @@ var group__spa__node =
       [ "SPA_NODE_COMMAND_Marker", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a64bf8f88cb260787a8b57ed830660469", null ],
       [ "SPA_NODE_COMMAND_ParamBegin", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60ab4505935610169df9fabbfdcdf473812", null ],
       [ "SPA_NODE_COMMAND_ParamEnd", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60acdab0f31c63fe3b66444558fed7440bd", null ],
-      [ "SPA_NODE_COMMAND_RequestProcess", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a0c040b68838602058673395761713bdc", null ]
+      [ "SPA_NODE_COMMAND_RequestProcess", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a0c040b68838602058673395761713bdc", null ],
+      [ "SPA_NODE_COMMAND_User", "group__spa__node.html#ggae5da16ead1c0ebe3f41d5b3ee27d4f60a927018822c4083c6849c977e09f038dc", null ]
+    ] ],
+    [ "spa_command_node", "group__spa__node.html#gac54b46ae25e476d2084c810ec528686d", [
+      [ "SPA_COMMAND_NODE_START", "group__spa__node.html#ggac54b46ae25e476d2084c810ec528686da61fca302000c499e89d8fcdbaffe422c", null ],
+      [ "SPA_COMMAND_NODE_START_User", "group__spa__node.html#ggac54b46ae25e476d2084c810ec528686da046c359fb9be50c5de1f41c1f7582edc", null ],
+      [ "SPA_COMMAND_NODE_extra", "group__spa__node.html#ggac54b46ae25e476d2084c810ec528686da790a13b92bfba4b92c2aa4e51fd4fda7", null ],
+      [ "SPA_COMMAND_NODE_START_CUSTOM", "group__spa__node.html#ggac54b46ae25e476d2084c810ec528686daca6eff67804b29464b7f7f03d1d3b1b0", null ]
     ] ],
     [ "spa_node_event", "group__spa__node.html#gadcbf11755fca00d5a654a79ee80fdb81", [
       [ "SPA_NODE_EVENT_Error", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a8390ac4315ffa1d12f262266becf5812", null ],
       [ "SPA_NODE_EVENT_Buffering", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81ad57a942adfadd9bb655418127a644b42", null ],
       [ "SPA_NODE_EVENT_RequestRefresh", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81af8d56477659a6f8817cf173004c94955", null ],
-      [ "SPA_NODE_EVENT_RequestProcess", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a53f96b85c26097dc07ed3b6e137b161f", null ]
+      [ "SPA_NODE_EVENT_RequestProcess", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a53f96b85c26097dc07ed3b6e137b161f", null ],
+      [ "SPA_NODE_EVENT_User", "group__spa__node.html#ggadcbf11755fca00d5a654a79ee80fdb81a4f44b645c593b57a2fa38043a042b029", null ]
     ] ],
     [ "spa_event_node", "group__spa__node.html#gae111175d27c9aa0b465b826bc55c9be1", [
-      [ "SPA_EVENT_NODE_START", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1ad73df09f7d608ee04395ad8162417fcd", null ]
+      [ "SPA_EVENT_NODE_START", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1ad73df09f7d608ee04395ad8162417fcd", null ],
+      [ "SPA_EVENT_NODE_START_User", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1a88d031aa03d180bce39fbe46dc3d06aa", null ],
+      [ "SPA_EVENT_NODE_extra", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1a72cba0e432a7701536ed48f42d1e72de", null ],
+      [ "SPA_EVENT_NODE_START_CUSTOM", "group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1a808d9213d5760ab48e61f73f741ce7f4", null ]
     ] ],
     [ "spa_io_type", "group__spa__node.html#ga89c01db6072aa9fd9ca5ac4dee9b6716", [
       [ "SPA_IO_Invalid", "group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ac69bf5ac901b028e6f303e5f1c79fab4", null ],
@@ -213,6 +227,9 @@ var group__spa__node =
     [ "SPA_IO_MEMORY_INIT", "group__spa__node.html#ga6e56edfd21e88945c056adc8d17dd045", null ],
     [ "SPA_IO_CLOCK_FLAG_FREEWHEEL", "group__spa__node.html#ga421d271b07d7650f6b8018668ea771c7", null ],
     [ "SPA_IO_CLOCK_FLAG_XRUN_RECOVER", "group__spa__node.html#ga59370627af55d7add7c558979dae2e97", null ],
+    [ "SPA_IO_CLOCK_FLAG_LAZY", "group__spa__node.html#gac0e2eda569c8cb5339731ff4bc773e3d", null ],
+    [ "SPA_IO_CLOCK_FLAG_NO_RATE", "group__spa__node.html#gac00ad42a0a1fdfe6606d20e2426eec28", null ],
+    [ "SPA_IO_CLOCK_FLAG_DISCONT", "group__spa__node.html#gaf04ddd89680660089ff19f133c0bba57", null ],
     [ "SPA_IO_VIDEO_SIZE_VALID", "group__spa__node.html#ga50542c161ad0906f67b4be78ab2e71cd", null ],
     [ "SPA_IO_SEGMENT_BAR_FLAG_VALID", "group__spa__node.html#ga8a153a40c392f4d78b1dd45156b29f7c", null ],
     [ "SPA_IO_SEGMENT_VIDEO_FLAG_VALID", "group__spa__node.html#gac10fd7265f330c673c51a5719aaa6daa", null ],
@@ -236,6 +253,7 @@ var group__spa__node =
     [ "SPA_KEY_PORT_MONITOR", "group__spa__node.html#gae091e85290ec8a7578f48c2b5a73affe", null ],
     [ "SPA_KEY_PORT_IGNORE_LATENCY", "group__spa__node.html#gad0584e7a902df3de92b8c2be0aa2ff53", null ],
     [ "SPA_KEY_PORT_GROUP", "group__spa__node.html#gab9f77936cc95797ac2e2ea13a85651ef", null ],
+    [ "SPA_API_NODE", "group__spa__node.html#ga2da432d6b52a14aa687ae93e501118b1", null ],
     [ "SPA_TYPE_INTERFACE_Node", "group__spa__node.html#ga5c57b4fb1d72db0725992bd91b858dd6", null ],
     [ "SPA_VERSION_NODE", "group__spa__node.html#ga856b63143b916ed8de520b98e46a18ce", null ],
     [ "SPA_NODE_CHANGE_MASK_FLAGS", "group__spa__node.html#ga6dc4d1bbfffa9f49d18168d5a8302459", null ],
@@ -297,31 +315,13 @@ var group__spa__node =
     [ "SPA_NODE_METHOD_PROCESS", "group__spa__node.html#ga02fe74bd20e4af4c6b51a22dfd7aee85", null ],
     [ "SPA_NODE_METHOD_NUM", "group__spa__node.html#gaf9f1bf717bf713b7c019934218c05a5c", null ],
     [ "SPA_VERSION_NODE_METHODS", "group__spa__node.html#gaee7d45b6819789bde3de86d9be592a3a", null ],
-    [ "spa_node_method", "group__spa__node.html#gaf6acc77e506b002f4af0ecd03e29c6ff", null ],
-    [ "spa_node_method_fast", "group__spa__node.html#ga3ad11e9ae12a8d68f35fa708e0fca6d5", null ],
-    [ "spa_node_add_listener", "group__spa__node.html#ga594ac9d44ca70f66f42b9deb408f0e51", null ],
-    [ "spa_node_set_callbacks", "group__spa__node.html#gafc6f880a7906ab6ad837b753b6c2de05", null ],
-    [ "spa_node_sync", "group__spa__node.html#gabb7d0304d2f9952bcf6b95041573c2a4", null ],
-    [ "spa_node_enum_params", "group__spa__node.html#gad62e2c5acaf8499bd307e16477ba1a97", null ],
-    [ "spa_node_set_param", "group__spa__node.html#gaa1b58b1433ccdb1e22550ed44981e1d4", null ],
-    [ "spa_node_set_io", "group__spa__node.html#ga2e8fde2df4533ca4b53da3a44d7bf233", null ],
-    [ "spa_node_send_command", "group__spa__node.html#gad8a56491e1cb021d5a6f168a538a6ae5", null ],
-    [ "spa_node_add_port", "group__spa__node.html#ga966406405be3cfd4d9e2e419d93aad0c", null ],
-    [ "spa_node_remove_port", "group__spa__node.html#ga1c48d90a1e89b65654a85da59ae267dd", null ],
-    [ "spa_node_port_enum_params", "group__spa__node.html#ga5d06b1bee8257f3c26d745018435bfb3", null ],
-    [ "spa_node_port_set_param", "group__spa__node.html#gaa26c9e47c911179baa62f25a335076b0", null ],
-    [ "spa_node_port_use_buffers", "group__spa__node.html#gaf7f6bdf00d83c8aaa4cb13c983ff3ff6", null ],
-    [ "spa_node_port_set_io", "group__spa__node.html#ga8c921a18a870cfc3163861b4fb7df6b1", null ],
-    [ "spa_node_port_reuse_buffer", "group__spa__node.html#ga78928697897c91bedd278b7ab72e8380", null ],
-    [ "spa_node_port_reuse_buffer_fast", "group__spa__node.html#ga9daa5c8e89a00eb95ba4571693cd1694", null ],
-    [ "spa_node_process", "group__spa__node.html#ga9d4577c9ba65dce198293c8b777ae874", null ],
-    [ "spa_node_process_fast", "group__spa__node.html#ga06f7bd68dcac9beb014db111b4e64b33", null ],
     [ "SPA_TYPE_INFO_IO", "group__spa__node.html#ga307753db51558b08071e4f2822228672", null ],
     [ "SPA_TYPE_INFO_IO_BASE", "group__spa__node.html#gaa8e30ee6ab74de00871c610bad6eeaf8", null ],
     [ "SPA_TYPE_INFO_NodeEvent", "group__spa__node.html#ga5716dde5392df4653ff81188fc6ed47e", null ],
     [ "SPA_TYPE_INFO_NODE_EVENT_BASE", "group__spa__node.html#ga8c831fdc677c869f88cc13d81c317939", null ],
     [ "SPA_TYPE_INFO_NodeCommand", "group__spa__node.html#ga698610695f5a9a80459847fa95a68621", null ],
     [ "SPA_TYPE_INFO_NODE_COMMAND_BASE", "group__spa__node.html#gac0b1456e0915963066c9a3cae842c9e1", null ],
+    [ "SPA_API_NODE_UTILS", "group__spa__node.html#gafae3807780faadd08ca051dd67df9e83", null ],
     [ "spa_node_emit", "group__spa__node.html#ga1dfd6ca0baebeb94f35fe58fe19b81d9", null ],
     [ "spa_node_emit_info", "group__spa__node.html#ga030c84ccc7f2f1190f1ef3b246756121", null ],
     [ "spa_node_emit_port_info", "group__spa__node.html#ga2dbb6c19156dd04a8b53bd08f30ae460", null ],
@@ -331,9 +331,26 @@ var group__spa__node =
     [ "spa_node_call_ready", "group__spa__node.html#gab23963cc540a69dc6c7f482e655d4b70", null ],
     [ "spa_node_call_reuse_buffer", "group__spa__node.html#gaf4fd1fa9983cfe26d6d3a08bc34c8230", null ],
     [ "spa_node_call_xrun", "group__spa__node.html#gae06e2ee893ca6c894411795b564161c6", null ],
-    [ "spa_result_func_node_params", "group__spa__node.html#ga1d8f1db76d8d38bbf1116c14108fb368", null ],
-    [ "spa_node_enum_params_sync", "group__spa__node.html#ga38d51bd4e324b9fa9f1289c8c41ee611", null ],
-    [ "spa_node_port_enum_params_sync", "group__spa__node.html#gaccf324882da5942ac8622af7760bff4d", null ],
+    [ "spa_node_add_listener", "group__spa__node.html#ga65c1f9654c6f4cf1376801b4f6065104", null ],
+    [ "spa_node_set_callbacks", "group__spa__node.html#gaeffcdd11ad19d355e57ae25378fe9cc9", null ],
+    [ "spa_node_sync", "group__spa__node.html#ga3b9c0b2887e99888d3ba1d8180b5fde9", null ],
+    [ "spa_node_enum_params", "group__spa__node.html#ga23213590c78f3fdcbef6b9122d47b596", null ],
+    [ "spa_node_set_param", "group__spa__node.html#ga901a6b3da6039cbe8490401e8167407a", null ],
+    [ "spa_node_set_io", "group__spa__node.html#ga0da59be3bb17f46311f79b5bd8d7647a", null ],
+    [ "spa_node_send_command", "group__spa__node.html#gad710aafcd4d4287625716561f880aec8", null ],
+    [ "spa_node_add_port", "group__spa__node.html#gaab0bad53489fb78c0341acda865bc5aa", null ],
+    [ "spa_node_remove_port", "group__spa__node.html#gaa8ac7c8ad273c18778ed3a271ccea4db", null ],
+    [ "spa_node_port_enum_params", "group__spa__node.html#gabca8824f5edd2552a0ed3bb1bd4bdda7", null ],
+    [ "spa_node_port_set_param", "group__spa__node.html#ga203870d59c78ded19a21a89f4398cb9d", null ],
+    [ "spa_node_port_use_buffers", "group__spa__node.html#gaa915c8f8867357b165dec434771ba7c1", null ],
+    [ "spa_node_port_set_io", "group__spa__node.html#ga83b965cda2d824b811dc07c6d2ffd304", null ],
+    [ "spa_node_port_reuse_buffer", "group__spa__node.html#ga95ba4d626af77e5aca2e653cf8af6b63", null ],
+    [ "spa_node_port_reuse_buffer_fast", "group__spa__node.html#gaff4df7847186e1d2ea1eff9119af56fa", null ],
+    [ "spa_node_process", "group__spa__node.html#gadd5dab2cd587836a9c950330a1ab66ab", null ],
+    [ "spa_node_process_fast", "group__spa__node.html#gafa841c2f69692b179e629e956b2f5441", null ],
+    [ "spa_result_func_node_params", "group__spa__node.html#ga2b4a4fd3a8b2db1f57f61ece5929c8ad", null ],
+    [ "spa_node_enum_params_sync", "group__spa__node.html#ga79deea2edc529cbd0baeb2dd33689bc7", null ],
+    [ "spa_node_port_enum_params_sync", "group__spa__node.html#gaa96092313f1e9653867961f1c8f6a15e", null ],
     [ "spa_type_io", "group__spa__node.html#gad296f95f21eece76aa6838734f1453b3", null ],
     [ "spa_type_node_event_id", "group__spa__node.html#gab13c0d45af673773c71f4a370384f4ec", null ],
     [ "spa_type_node_event", "group__spa__node.html#ga90709238b87febc59d242d7fdd881f3c", null ],
